"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var glob_test_ids_1 = require("./glob-test-ids");
var setupMocks = function (_a) {
    var testIds = _a.testIds;
    var fs = {
        readFileSync: jest.fn().mockReturnValue(JSON.stringify(testIds)),
        mkdirpSync: jest.fn(),
        writeFileSync: jest.fn()
    };
    var path = {
        join: jest.fn().mockReturnValue("outfile"),
        dirname: jest.fn().mockReturnValue("dirname")
    };
    var glob = {
        sync: jest.fn().mockReturnValue(["filename"])
    };
    var fn = glob_test_ids_1.globTestIds({ fs: fs, glob: glob, path: path });
    return {
        fs: fs,
        path: path,
        glob: glob,
        fn: fn
    };
};
describe("globTestIds", function () {
    it("reads all test ids and writes to json file", function () {
        var _a = setupMocks({ testIds: ["test-id"] }), fs = _a.fs, path = _a.path, glob = _a.glob, fn = _a.fn;
        fn({
            idsLocation: "./test",
            output: "./master.json",
            cwd: "/test/dir/"
        });
        expect(fs.readFileSync.mock.calls).toMatchSnapshot("fs.readFileSync");
        expect(fs.mkdirpSync.mock.calls).toMatchSnapshot("fs.mkdirpSync");
        expect(fs.writeFileSync.mock.calls).toMatchSnapshot("fs.writeFileSync");
        expect(path.join.mock.calls).toMatchSnapshot("path.join");
        expect(path.dirname.mock.calls).toMatchSnapshot("path.dirname");
        expect(glob.sync.mock.calls).toMatchSnapshot("glob.sync");
    });
    it("throws if there are duplicate test ids", function () {
        var fn = setupMocks({
            testIds: ["test-id", "test-id"]
        }).fn;
        expect(function () {
            return fn({
                idsLocation: "./test",
                output: "./master.json",
                cwd: "/test/dir/"
            });
        }).toThrowErrorMatchingSnapshot();
    });
});
//# sourceMappingURL=glob-test-ids.test.js.map